@@ -1,5 +1,5 @@
+# frozen_string_literal: true
 require_relative 'helper'
-require 'sidekiq/redis_connection'
 
 class TestRedisConnection < Sidekiq::Test
 
@@ -27,11 +27,16 @@ class TestRedisConnection < Sidekiq::Test
     end
 
     describe "namespace" do
-      it "uses a given :namespace" do
+      it "uses a given :namespace set by a symbol key" do
         pool = Sidekiq::RedisConnection.create(:namespace => "xxx")
         assert_equal "xxx", pool.checkout.namespace
       end
 
+      it "uses a given :namespace set by a string key" do
+        pool = Sidekiq::RedisConnection.create("namespace" => "xxx")
+        assert_equal "xxx", pool.checkout.namespace
+      end
+
       it "uses given :namespace over :namespace from Sidekiq.options" do
         Sidekiq.options[:namespace] = "xxx"
         pool = Sidekiq::RedisConnection.create(:namespace => "yyy")
